//
// Copyright (c) 2000 by Tech Soft 3D, LLC.
// The information contained herein is confidential and proprietary to
// Tech Soft 3D, LLC., and considered a trade secret as defined under
// civil and criminal statutes.  Tech Soft 3D shall pursue its civil
// and criminal remedies in the event of unauthorized use or misappropriation
// of its trade secrets.  Use of this information by anyone other than
// authorized employees of Tech Soft 3D, LLC. is granted only under a
// written non-disclosure agreement, expressly prescribing the scope and
// manner of such use.
//
// $Id: 972aa2ce06e68270784edd97137ef53cb692bcb6 $
//

// HOpConstructRectangle.h : interface of the HOpConstruction class
// draws a 2D box in view port based on pointer first position and last position
// Derived classes access the Points for the rectangle in HBaseOperator members
// m_ptFirst and m_ptLast; Points are stored in window space.


#ifndef _HOPCONSTRUCTRECTANGLE_H
#define _HOPCONSTRUCTRECTANGLE_H

#include "HTools.h"
#include "HBaseOperator.h"

//! The HOpConstructRectangle class draws a rectangle. 
/*! 
  HOpConstructRectangle implements three of the mouse button event handlers and maps the event information to the HOOPS 
  routine HC_Insert_Rectangle. This provides the basic functionality for drawing a temporary, overlayed 2-D box outline in the view plane based on 
  first and last pointer positions. The operation consists of the following steps:
  <ol>
  <li>Left Button Down:				first point of rectangle
  <li>Left Button Down and Drag:	rubberband rectangle to desired dimensions
  <li>Left Button Up:				rectangle finalized and the polyline primitive used to represent the rectangle is flushed from the scene
  </ol>
  More Detailed Description: see event methods 
*/
class MVO_API HOpConstructRectangle : public HBaseOperator
{
public:

  	HOpConstructRectangle(HBaseView* view, int DoRepeat=0, int DoCapture=1, bool UseCenterMarker=true);
	~HOpConstructRectangle();

    void GetName(char *name);

	HBaseOperator * Clone();
    
protected:
	virtual int OnLButtonDown(HEventInfo &event);
    virtual int OnLButtonDownAndMove(HEventInfo &event);
	virtual int OnLButtonUp(HEventInfo &event); 
	
	bool	m_bRectangleExists;
	HPoint	m_ptRectangle[2];  /*!< First and last points in the rectangle, stored in window space */

private:
	bool	m_bUseCenterMarker;	
};
#endif
