/*
 * This demo shows how to set the ambient light component of a light using
 * the base stream toolkit.
 */


#include <BStream.h>
#include <stdio.h>

static void WriteObject(BBaseOpcodeHandler*, BStreamFileToolkit*, FILE*, char*r, int);

int main(){
	char mybuffer[4096];
	int size = 4096;
	
    FILE *flptr = fopen( "temp.hsf", "wb");
	
	BStreamFileToolkit mytoolkit;
    mytoolkit.PrepareBuffer(mybuffer, size);

    TK_Header header;
    WriteObject(&header, &mytoolkit, flptr, mybuffer, size);

    TK_Point point( TKE_Distant_Light );
	point.SetPoint(1,1,1);
    WriteObject(&point, &mytoolkit, flptr, mybuffer, size);

	TK_Geometry_Attributes attrib;
    WriteObject(&attrib, &mytoolkit, flptr, mybuffer, size);

	TK_Color color;
	color.SetDiffuse( 1, 0, 0 );
	color.SetGeometry( TKO_Geo_Ambient );
	WriteObject(&color, &mytoolkit, flptr, mybuffer, size);

	TK_Terminator term( TKE_Termination );
	//Terminate the geometry attribute list
	WriteObject(&term, &mytoolkit, flptr, mybuffer, size);
	//Terminate the HSF file
	WriteObject(&term, &mytoolkit, flptr, mybuffer, size);
	
	size = mytoolkit.CurrentBufferLength();
	fwrite(mybuffer, sizeof(char), size, flptr);

	fclose(flptr);
	return 0;
}


static void WriteObject(BBaseOpcodeHandler * handler, BStreamFileToolkit * tk, FILE * fp,
                        char * buffer, int size) 
{
    TK_Status status;

    // ask the toolkit to write out the object; the toolkit will write out as much as
    // the current buffer can hold
    status = handler->Write(*tk);

    // if there is still more data left to write; we have to loop through 
    // generating and writing buffers of data until we're done
    while (status == TK_Pending) 
    {
        // due to compression, preparing a new buffer might immediately fill that buffer
        // so we need an extra check to possibly export that buffer and prepare a new buffer
        while (status == TK_Pending) 
        {
            // ask the toolkit how much of the buffer is currently filled
            // this will normally be the same as the buffer size that we passed in
            int count = tk->CurrentBufferLength();

            // write the current out to our file since this example deals with 
            // exporting a file; however, instead of writing to a file, the buffer of
            // data could be sent to an application data-structure, or transmitted
            // over a network ('streamed'), etc...
            fwrite(buffer, sizeof (char), count, fp);

            // tell the toolkit where it can resume writing data; in this case, we
            // can reuse the same buffer once we're done with it
            status = tk->PrepareBuffer(buffer, size);
        }

        // ask the toolkit to continue trying to write out the object's data
        status = handler->Write(*tk);
    }
}
